You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2019/05/16 06:59:36 UTC

[camel] branch master updated: CAMEL-13528: Rename chiper to cipher

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/camel.git


The following commit(s) were added to refs/heads/master by this push:
     new 9025b8b  CAMEL-13528: Rename chiper to cipher
9025b8b is described below

commit 9025b8b9c3adbf1b548a5c1ac43bbcd9a7c2d0fa
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Thu May 16 08:58:43 2019 +0200

    CAMEL-13528: Rename chiper to cipher
---
 MIGRATION.md                                           |  2 ++
 .../camel-spring-boot/src/main/docs/spring-boot.adoc   |  2 +-
 .../camel/spring/boot/CamelAutoConfiguration.java      |  2 +-
 .../spring/boot/CamelConfigurationProperties.java      | 12 ++++++------
 .../org/apache/camel/spi/StreamCachingStrategy.java    |  6 +++---
 .../camel/support/jsse/BaseSSLContextParameters.java   |  2 +-
 .../impl/engine/DefaultStreamCachingStrategy.java      | 12 ++++++------
 .../core/xml/AbstractCamelContextFactoryBean.java      |  6 +++---
 .../core/xml/CamelStreamCachingStrategyDefinition.java | 12 ++++++------
 .../apache/camel/main/MainConfigurationProperties.java | 18 +++++++++---------
 .../main/java/org/apache/camel/main/MainSupport.java   |  2 +-
 .../camel/converter/stream/CachedOutputStreamTest.java |  2 +-
 .../mbean/ManagedStreamCachingStrategyMBean.java       |  4 ++--
 .../management/mbean/ManagedStreamCachingStrategy.java |  4 ++--
 .../management/ManagedStreamCachingStrategyTest.java   |  4 ++--
 .../camel/converter/stream/FileInputStreamCache.java   |  4 ++--
 docs/components/modules/ROOT/pages/spring-boot.adoc    |  2 +-
 17 files changed, 49 insertions(+), 47 deletions(-)

diff --git a/MIGRATION.md b/MIGRATION.md
index 74886a7..c8766a8 100644
--- a/MIGRATION.md
+++ b/MIGRATION.md
@@ -242,6 +242,8 @@ The annotation `org.apache.camel.Constant` has been removed, use `@Simple` inste
 
 The annotation `org.apache.camel.language.SpEL` has been moved to `org.apache.camel.language.spel.SpEL` and in the `camel-spring` JAR.
 
+Rename various APIs in camel-core to fix the typo `chiper` to `cipher`.
+
 #### camel-test
 
 If you are using camel-test and override the `createRegistry` method, for example to register beans from the `JndiRegisty` class, then this is no longer necessary, and instead
diff --git a/components/camel-spring-boot/src/main/docs/spring-boot.adoc b/components/camel-spring-boot/src/main/docs/spring-boot.adoc
index 2136383..679a7e7 100644
--- a/components/camel-spring-boot/src/main/docs/spring-boot.adoc
+++ b/components/camel-spring-boot/src/main/docs/spring-boot.adoc
@@ -178,7 +178,7 @@ The component supports 140 options, which are listed below.
 | *camel.springboot.stream-caching-buffer-size* | Sets the stream caching buffer size to use when allocating in-memory buffers used for in-memory stream caches. The default size is 4096. | 0 | Integer
 | *camel.springboot.stream-caching-enabled* | Sets whether stream caching is enabled or not. Default is false. | false | Boolean
 | *camel.springboot.stream-caching-remove-spool-directory-when-stopping* | Whether to remove stream caching temporary directory when stopping. This option is default true. | true | Boolean
-| *camel.springboot.stream-caching-spool-chiper* | Sets a stream caching chiper name to use when spooling to disk to write with encryption. By default the data is not encrypted. |  | String
+| *camel.springboot.stream-caching-spool-cipher* | Sets a stream caching cipher name to use when spooling to disk to write with encryption. By default the data is not encrypted. |  | String
 | *camel.springboot.stream-caching-spool-directory* | Sets the stream caching spool (temporary) directory to use for overflow and spooling to disk. If no spool directory has been explicit configured, then a temporary directory is created in the java.io.tmpdir directory. |  | String
 | *camel.springboot.stream-caching-spool-threshold* | Stream caching threshold in bytes when overflow to disk is activated. The default threshold is 128kb. Use -1 to disable overflow to disk. | 0 | Long
 | *camel.springboot.stream-caching-spool-used-heap-memory-limit* | Sets what the upper bounds should be when streamCachingSpoolUsedHeapMemoryThreshold is in use. |  | String
diff --git a/components/camel-spring-boot/src/main/java/org/apache/camel/spring/boot/CamelAutoConfiguration.java b/components/camel-spring-boot/src/main/java/org/apache/camel/spring/boot/CamelAutoConfiguration.java
index 69728ca..8ec9f2a 100644
--- a/components/camel-spring-boot/src/main/java/org/apache/camel/spring/boot/CamelAutoConfiguration.java
+++ b/components/camel-spring-boot/src/main/java/org/apache/camel/spring/boot/CamelAutoConfiguration.java
@@ -176,7 +176,7 @@ public class CamelAutoConfiguration {
         camelContext.getStreamCachingStrategy().setAnySpoolRules(config.isStreamCachingAnySpoolRules());
         camelContext.getStreamCachingStrategy().setBufferSize(config.getStreamCachingBufferSize());
         camelContext.getStreamCachingStrategy().setRemoveSpoolDirectoryWhenStopping(config.isStreamCachingRemoveSpoolDirectoryWhenStopping());
-        camelContext.getStreamCachingStrategy().setSpoolChiper(config.getStreamCachingSpoolChiper());
+        camelContext.getStreamCachingStrategy().setSpoolCipher(config.getStreamCachingSpoolCipher());
         if (config.getStreamCachingSpoolDirectory() != null) {
             camelContext.getStreamCachingStrategy().setSpoolDirectory(config.getStreamCachingSpoolDirectory());
         }
diff --git a/core/camel-api/src/main/java/org/apache/camel/support/jsse/BaseSSLContextParameters.java b/core/camel-api/src/main/java/org/apache/camel/support/jsse/BaseSSLContextParameters.java
index da3af59..31d5c3f 100644
--- a/core/camel-api/src/main/java/org/apache/camel/support/jsse/BaseSSLContextParameters.java
+++ b/core/camel-api/src/main/java/org/apache/camel/support/jsse/BaseSSLContextParameters.java
@@ -828,7 +828,7 @@ public abstract class BaseSSLContextParameters extends JsseParameters {
         @Override
         public String toString() {
             return String.format("SSLContext[hash=%h, provider=%s, protocol=%s, needClientAuth=%s, " 
-                + "wantClientAuth=%s\n\tdefaultProtocols=%s\n\tdefaultChiperSuites=%s\n\tsupportedProtocols=%s\n\tsupportedChiperSuites=%s\n]",
+                + "wantClientAuth=%s\n\tdefaultProtocols=%s\n\tdefaultCipherSuites=%s\n\tsupportedProtocols=%s\n\tsupportedCipherSuites=%s\n]",
                 hashCode(), getProvider(), getProtocol(), getDefaultSSLParameters().getNeedClientAuth(), getDefaultSSLParameters().getWantClientAuth(),
                 collectionAsCommaDelimitedString(getDefaultSSLParameters().getProtocols()),
                 collectionAsCommaDelimitedString(getDefaultSSLParameters().getCipherSuites()),
diff --git a/core/camel-base/src/main/java/org/apache/camel/impl/engine/DefaultStreamCachingStrategy.java b/core/camel-base/src/main/java/org/apache/camel/impl/engine/DefaultStreamCachingStrategy.java
index 20c4144..e04c6e5 100644
--- a/core/camel-base/src/main/java/org/apache/camel/impl/engine/DefaultStreamCachingStrategy.java
+++ b/core/camel-base/src/main/java/org/apache/camel/impl/engine/DefaultStreamCachingStrategy.java
@@ -46,7 +46,7 @@ public class DefaultStreamCachingStrategy extends ServiceSupport implements Came
     private long spoolThreshold = StreamCache.DEFAULT_SPOOL_THRESHOLD;
     private int spoolUsedHeapMemoryThreshold;
     private SpoolUsedHeapMemoryLimit spoolUsedHeapMemoryLimit;
-    private String spoolChiper;
+    private String spoolCipher;
     private int bufferSize = IOHelper.DEFAULT_BUFFER_SIZE;
     private boolean removeSpoolDirectoryWhenStopping = true;
     private final UtilizationStatistics statistics = new UtilizationStatistics();
@@ -105,12 +105,12 @@ public class DefaultStreamCachingStrategy extends ServiceSupport implements Came
         this.spoolThreshold = spoolThreshold;
     }
 
-    public String getSpoolChiper() {
-        return spoolChiper;
+    public String getSpoolCipher() {
+        return spoolCipher;
     }
 
-    public void setSpoolChiper(String spoolChiper) {
-        this.spoolChiper = spoolChiper;
+    public void setSpoolCipher(String spoolCipher) {
+        this.spoolCipher = spoolCipher;
     }
 
     public int getBufferSize() {
@@ -299,7 +299,7 @@ public class DefaultStreamCachingStrategy extends ServiceSupport implements Came
     public String toString() {
         return "DefaultStreamCachingStrategy["
             + "spoolDirectory=" + spoolDirectory
-            + ", spoolChiper=" + spoolChiper
+            + ", spoolCipher=" + spoolCipher
             + ", spoolThreshold=" + spoolThreshold
             + ", spoolUsedHeapMemoryThreshold=" + spoolUsedHeapMemoryThreshold
             + ", bufferSize=" + bufferSize
diff --git a/core/camel-core-xml/src/main/java/org/apache/camel/core/xml/AbstractCamelContextFactoryBean.java b/core/camel-core-xml/src/main/java/org/apache/camel/core/xml/AbstractCamelContextFactoryBean.java
index 6c97b2d..94f2de6 100644
--- a/core/camel-core-xml/src/main/java/org/apache/camel/core/xml/AbstractCamelContextFactoryBean.java
+++ b/core/camel-core-xml/src/main/java/org/apache/camel/core/xml/AbstractCamelContextFactoryBean.java
@@ -584,9 +584,9 @@ public abstract class AbstractCamelContextFactoryBean<T extends ModelCamelContex
             StreamCachingStrategy.SpoolUsedHeapMemoryLimit ul = CamelContextHelper.mandatoryConvertTo(getContext(), StreamCachingStrategy.SpoolUsedHeapMemoryLimit.class, limit);
             getContext().getStreamCachingStrategy().setSpoolUsedHeapMemoryLimit(ul);
         }
-        String spoolChiper = CamelContextHelper.parseText(getContext(), streamCaching.getSpoolChiper());
-        if (spoolChiper != null) {
-            getContext().getStreamCachingStrategy().setSpoolChiper(spoolChiper);
+        String spoolCipher = CamelContextHelper.parseText(getContext(), streamCaching.getSpoolCipher());
+        if (spoolCipher != null) {
+            getContext().getStreamCachingStrategy().setSpoolCipher(spoolCipher);
         }
         Boolean remove = CamelContextHelper.parseBoolean(getContext(), streamCaching.getRemoveSpoolDirectoryWhenStopping());
         if (remove != null) {
diff --git a/core/camel-core/src/main/java/org/apache/camel/main/MainSupport.java b/core/camel-core/src/main/java/org/apache/camel/main/MainSupport.java
index 7296bd1..b4152b3 100644
--- a/core/camel-core/src/main/java/org/apache/camel/main/MainSupport.java
+++ b/core/camel-core/src/main/java/org/apache/camel/main/MainSupport.java
@@ -924,7 +924,7 @@ public abstract class MainSupport extends ServiceSupport {
         camelContext.getStreamCachingStrategy().setAnySpoolRules(config.isStreamCachingAnySpoolRules());
         camelContext.getStreamCachingStrategy().setBufferSize(config.getStreamCachingBufferSize());
         camelContext.getStreamCachingStrategy().setRemoveSpoolDirectoryWhenStopping(config.isStreamCachingRemoveSpoolDirectoryWhenStopping());
-        camelContext.getStreamCachingStrategy().setSpoolChiper(config.getStreamCachingSpoolChiper());
+        camelContext.getStreamCachingStrategy().setSpoolCipher(config.getStreamCachingSpoolCipher());
         if (config.getStreamCachingSpoolDirectory() != null) {
             camelContext.getStreamCachingStrategy().setSpoolDirectory(config.getStreamCachingSpoolDirectory());
         }
diff --git a/core/camel-core/src/test/java/org/apache/camel/converter/stream/CachedOutputStreamTest.java b/core/camel-core/src/test/java/org/apache/camel/converter/stream/CachedOutputStreamTest.java
index 8d2c087..659bdf0 100644
--- a/core/camel-core/src/test/java/org/apache/camel/converter/stream/CachedOutputStreamTest.java
+++ b/core/camel-core/src/test/java/org/apache/camel/converter/stream/CachedOutputStreamTest.java
@@ -142,7 +142,7 @@ public class CachedOutputStreamTest extends ContextTestSupport {
     @Test
     public void testCacheStreamToFileAndCloseStreamEncrypted() throws Exception {
         // set some stream or 8-bit block cipher transformation name
-        context.getStreamCachingStrategy().setSpoolChiper("RC4");
+        context.getStreamCachingStrategy().setSpoolCipher("RC4");
 
         context.start();
 
diff --git a/core/camel-management-api/src/main/java/org/apache/camel/api/management/mbean/ManagedStreamCachingStrategyMBean.java b/core/camel-management-api/src/main/java/org/apache/camel/api/management/mbean/ManagedStreamCachingStrategyMBean.java
index a2ad17c..12fc23c 100644
--- a/core/camel-management-api/src/main/java/org/apache/camel/api/management/mbean/ManagedStreamCachingStrategyMBean.java
+++ b/core/camel-management-api/src/main/java/org/apache/camel/api/management/mbean/ManagedStreamCachingStrategyMBean.java
@@ -34,8 +34,8 @@ public interface ManagedStreamCachingStrategyMBean extends ManagedServiceMBean {
     @ManagedAttribute(description = "Directory used when overflow and spooling to disk")
     String getSpoolDirectory();
 
-    @ManagedAttribute(description = "Chiper used if writing with encryption")
-    String getSpoolChiper();
+    @ManagedAttribute(description = "Cipher used if writing with encryption")
+    String getSpoolCipher();
 
     @ManagedAttribute(description = "Threshold in bytes when overflow and spooling to disk instead of keeping in memory")
     void setSpoolThreshold(long threshold);
diff --git a/core/camel-management-impl/src/main/java/org/apache/camel/management/mbean/ManagedStreamCachingStrategy.java b/core/camel-management-impl/src/main/java/org/apache/camel/management/mbean/ManagedStreamCachingStrategy.java
index 5d03623..5b7ce66 100644
--- a/core/camel-management-impl/src/main/java/org/apache/camel/management/mbean/ManagedStreamCachingStrategy.java
+++ b/core/camel-management-impl/src/main/java/org/apache/camel/management/mbean/ManagedStreamCachingStrategy.java
@@ -49,8 +49,8 @@ public class ManagedStreamCachingStrategy extends ManagedService implements Mana
         return streamCachingStrategy.getSpoolDirectory().getPath();
     }
 
-    public String getSpoolChiper() {
-        return streamCachingStrategy.getSpoolChiper();
+    public String getSpoolCipher() {
+        return streamCachingStrategy.getSpoolCipher();
     }
 
     public void setSpoolThreshold(long threshold) {
diff --git a/core/camel-management-impl/src/test/java/org/apache/camel/management/ManagedStreamCachingStrategyTest.java b/core/camel-management-impl/src/test/java/org/apache/camel/management/ManagedStreamCachingStrategyTest.java
index a85c3e6..adf0891 100644
--- a/core/camel-management-impl/src/test/java/org/apache/camel/management/ManagedStreamCachingStrategyTest.java
+++ b/core/camel-management-impl/src/test/java/org/apache/camel/management/ManagedStreamCachingStrategyTest.java
@@ -76,8 +76,8 @@ public class ManagedStreamCachingStrategyTest extends ManagementTestSupport {
         cacheSize = (Long) mbeanServer.getAttribute(name, "CacheSpoolSize");
         assertEquals(0, cacheSize.longValue());
 
-        String chiper = (String) mbeanServer.getAttribute(name, "SpoolChiper");
-        assertNull(chiper);
+        String cipher = (String) mbeanServer.getAttribute(name, "SpoolCipher");
+        assertNull(cipher);
 
         Boolean remove = (Boolean) mbeanServer.getAttribute(name, "RemoveSpoolDirectoryWhenStopping");
         assertEquals(Boolean.TRUE, remove);
diff --git a/core/camel-support/src/main/java/org/apache/camel/converter/stream/FileInputStreamCache.java b/core/camel-support/src/main/java/org/apache/camel/converter/stream/FileInputStreamCache.java
index 94e54ca..c2df16c 100644
--- a/core/camel-support/src/main/java/org/apache/camel/converter/stream/FileInputStreamCache.java
+++ b/core/camel-support/src/main/java/org/apache/camel/converter/stream/FileInputStreamCache.java
@@ -241,10 +241,10 @@ public final class FileInputStreamCache extends InputStream implements StreamCac
 
             LOG.trace("Creating temporary stream cache file: {}", tempFile);
             OutputStream out = new BufferedOutputStream(Files.newOutputStream(tempFile.toPath(), StandardOpenOption.CREATE, StandardOpenOption.WRITE));
-            if (ObjectHelper.isNotEmpty(strategy.getSpoolChiper())) {
+            if (ObjectHelper.isNotEmpty(strategy.getSpoolCipher())) {
                 try {
                     if (ciphers == null) {
-                        ciphers = new CipherPair(strategy.getSpoolChiper());
+                        ciphers = new CipherPair(strategy.getSpoolCipher());
                     }
                 } catch (GeneralSecurityException e) {
                     throw new IOException(e.getMessage(), e);
diff --git a/docs/components/modules/ROOT/pages/spring-boot.adoc b/docs/components/modules/ROOT/pages/spring-boot.adoc
index 2136383..679a7e7 100644
--- a/docs/components/modules/ROOT/pages/spring-boot.adoc
+++ b/docs/components/modules/ROOT/pages/spring-boot.adoc
@@ -178,7 +178,7 @@ The component supports 140 options, which are listed below.
 | *camel.springboot.stream-caching-buffer-size* | Sets the stream caching buffer size to use when allocating in-memory buffers used for in-memory stream caches. The default size is 4096. | 0 | Integer
 | *camel.springboot.stream-caching-enabled* | Sets whether stream caching is enabled or not. Default is false. | false | Boolean
 | *camel.springboot.stream-caching-remove-spool-directory-when-stopping* | Whether to remove stream caching temporary directory when stopping. This option is default true. | true | Boolean
-| *camel.springboot.stream-caching-spool-chiper* | Sets a stream caching chiper name to use when spooling to disk to write with encryption. By default the data is not encrypted. |  | String
+| *camel.springboot.stream-caching-spool-cipher* | Sets a stream caching cipher name to use when spooling to disk to write with encryption. By default the data is not encrypted. |  | String
 | *camel.springboot.stream-caching-spool-directory* | Sets the stream caching spool (temporary) directory to use for overflow and spooling to disk. If no spool directory has been explicit configured, then a temporary directory is created in the java.io.tmpdir directory. |  | String
 | *camel.springboot.stream-caching-spool-threshold* | Stream caching threshold in bytes when overflow to disk is activated. The default threshold is 128kb. Use -1 to disable overflow to disk. | 0 | Long
 | *camel.springboot.stream-caching-spool-used-heap-memory-limit* | Sets what the upper bounds should be when streamCachingSpoolUsedHeapMemoryThreshold is in use. |  | String
diff --git a/components/camel-spring-boot/src/main/java/org/apache/camel/spring/boot/CamelConfigurationProperties.java b/components/camel-spring-boot/src/main/java/org/apache/camel/spring/boot/CamelConfigurationProperties.java
index a3d8b25..de03247 100644
--- a/components/camel-spring-boot/src/main/java/org/apache/camel/spring/boot/CamelConfigurationProperties.java
+++ b/components/camel-spring-boot/src/main/java/org/apache/camel/spring/boot/CamelConfigurationProperties.java
@@ -227,10 +227,10 @@ public class CamelConfigurationProperties {
     private String streamCachingSpoolDirectory;
 
     /**
      * Sets a stream caching chiper name to use when spooling to disk to write with encryption.
      * By default the data is not encrypted.
      */
-    private String streamCachingSpoolChiper;
+    private String streamCachingSpoolCipher;
 
     /**
      * Stream caching threshold in bytes when overflow to disk is activated.
@@ -666,12 +666,12 @@ public class CamelConfigurationProperties {
         this.streamCachingSpoolDirectory = streamCachingSpoolDirectory;
     }
 
-    public String getStreamCachingSpoolChiper() {
-        return streamCachingSpoolChiper;
+    public String getStreamCachingSpoolCipher() {
+        return streamCachingSpoolCipher;
     }
 
-    public void setStreamCachingSpoolChiper(String streamCachingSpoolChiper) {
-        this.streamCachingSpoolChiper = streamCachingSpoolChiper;
+    public void setStreamCachingSpoolCipher(String streamCachingSpoolCipher) {
+        this.streamCachingSpoolCipher = streamCachingSpoolCipher;
     }
 
     public long getStreamCachingSpoolThreshold() {
@@ -227,10 +227,10 @@ public class CamelConfigurationProperties {
 
     /**
-     * Sets a stream caching chiper name to use when spooling to disk to write with encryption.
+     * Sets a stream caching cipher name to use when spooling to disk to write with encryption.
      * By default the data is not encrypted.
      */
diff --git a/core/camel-api/src/main/java/org/apache/camel/spi/StreamCachingStrategy.java b/core/camel-api/src/main/java/org/apache/camel/spi/StreamCachingStrategy.java
index fb09478..4860531 100644
--- a/core/camel-api/src/main/java/org/apache/camel/spi/StreamCachingStrategy.java
+++ b/core/camel-api/src/main/java/org/apache/camel/spi/StreamCachingStrategy.java
@@ -165,13 +165,13 @@ public interface StreamCachingStrategy extends StaticService {
     int getBufferSize();
 
     /**
      * Sets a chiper name to use when spooling to disk to write with encryption.
      * <p/>
      * By default the data is not encrypted.
      */
-    void setSpoolChiper(String chiper);
+    void setSpoolCipher(String cipher);
 
-    String getSpoolChiper();
+    String getSpoolCipher();
 
     /**
      * Whether to remove the temporary directory when stopping.
@@ -165,13 +165,13 @@ public interface StreamCachingStrategy extends StaticService {
 
     /**
-     * Sets a chiper name to use when spooling to disk to write with encryption.
+     * Sets a cipher name to use when spooling to disk to write with encryption.
      * <p/>
      * By default the data is not encrypted.
diff --git a/core/camel-core-xml/src/main/java/org/apache/camel/core/xml/CamelStreamCachingStrategyDefinition.java b/core/camel-core-xml/src/main/java/org/apache/camel/core/xml/CamelStreamCachingStrategyDefinition.java
index 17671fe..5ca4588 100644
--- a/core/camel-core-xml/src/main/java/org/apache/camel/core/xml/CamelStreamCachingStrategyDefinition.java
+++ b/core/camel-core-xml/src/main/java/org/apache/camel/core/xml/CamelStreamCachingStrategyDefinition.java
@@ -37,7 +37,7 @@ public class CamelStreamCachingStrategyDefinition extends IdentifiedType {
     @XmlAttribute
     private String spoolDirectory;
     @XmlAttribute
-    private String spoolChiper;
+    private String spoolCipher;
     @XmlAttribute
     private String spoolThreshold;
     @XmlAttribute
@@ -82,17 +82,17 @@ public class CamelStreamCachingStrategyDefinition extends IdentifiedType {
         this.spoolDirectory = spoolDirectory;
     }
 
-    public String getSpoolChiper() {
-        return spoolChiper;
+    public String getSpoolCipher() {
+        return spoolCipher;
     }
 
     /**
      * Sets a chiper name to use when spooling to disk to write with encryption.
      * <p/>
      * By default the data is not encrypted.
      */
-    public void setSpoolChiper(String spoolChiper) {
-        this.spoolChiper = spoolChiper;
+    public void setSpoolCipher(String spoolCipher) {
+        this.spoolCipher = spoolCipher;
     }
 
     public String getSpoolThreshold() {
@@ -82,17 +82,17 @@ public class CamelStreamCachingStrategyDefinition extends IdentifiedType {
 
     /**
-     * Sets a chiper name to use when spooling to disk to write with encryption.
+     * Sets a cipher name to use when spooling to disk to write with encryption.
      * <p/>
      * By default the data is not encrypted.
diff --git a/core/camel-core/src/main/java/org/apache/camel/main/MainConfigurationProperties.java b/core/camel-core/src/main/java/org/apache/camel/main/MainConfigurationProperties.java
index 86933b1..831dd97 100644
--- a/core/camel-core/src/main/java/org/apache/camel/main/MainConfigurationProperties.java
+++ b/core/camel-core/src/main/java/org/apache/camel/main/MainConfigurationProperties.java
@@ -44,7 +44,7 @@ public class MainConfigurationProperties {
     private int logDebugMaxChars;
     private boolean streamCachingEnabled;
     private String streamCachingSpoolDirectory;
-    private String streamCachingSpoolChiper;
+    private String streamCachingSpoolCipher;
     private long streamCachingSpoolThreshold;
     private int streamCachingSpoolUsedHeapMemoryThreshold;
     private String streamCachingSpoolUsedHeapMemoryLimit;
@@ -304,16 +304,16 @@ public class MainConfigurationProperties {
         this.streamCachingSpoolDirectory = streamCachingSpoolDirectory;
     }
 
-    public String getStreamCachingSpoolChiper() {
-        return streamCachingSpoolChiper;
+    public String getStreamCachingSpoolCipher() {
+        return streamCachingSpoolCipher;
     }
 
     /**
      * Sets a stream caching chiper name to use when spooling to disk to write with encryption.
      * By default the data is not encrypted.
      */
-    public void setStreamCachingSpoolChiper(String streamCachingSpoolChiper) {
-        this.streamCachingSpoolChiper = streamCachingSpoolChiper;
+    public void setStreamCachingSpoolCipher(String streamCachingSpoolCipher) {
+        this.streamCachingSpoolCipher = streamCachingSpoolCipher;
     }
 
     public long getStreamCachingSpoolThreshold() {
@@ -866,11 +866,11 @@ public class MainConfigurationProperties {
     }
 
     /**
      * Sets a stream caching chiper name to use when spooling to disk to write with encryption.
      * By default the data is not encrypted.
      */
-    public MainConfigurationProperties withStreamCachingSpoolChiper(String streamCachingSpoolChiper) {
-        this.streamCachingSpoolChiper = streamCachingSpoolChiper;
+    public MainConfigurationProperties withStreamCachingSpoolCipher(String streamCachingSpoolCipher) {
+        this.streamCachingSpoolCipher = streamCachingSpoolCipher;
         return this;
     }
 
@@ -304,16 +304,16 @@ public class MainConfigurationProperties {
 
     /**
-     * Sets a stream caching chiper name to use when spooling to disk to write with encryption.
+     * Sets a stream caching cipher name to use when spooling to disk to write with encryption.
      * By default the data is not encrypted.
      */
@@ -866,11 +866,11 @@ public class MainConfigurationProperties {
 
     /**
-     * Sets a stream caching chiper name to use when spooling to disk to write with encryption.
+     * Sets a stream caching cipher name to use when spooling to disk to write with encryption.
      * By default the data is not encrypted.
      */